@@ -30,6 +30,9 @@ class ReleaseNotesDirective(rst.Directive):
 
     has_content = True
 
+    # FIXME(dhellmann): We should be able to build this information
+    # from the configuration options so we don't have to edit it
+    # manually when we add new options.
     option_spec = {
         'branch': directives.unchanged,
         'reporoot': directives.unchanged,
@@ -39,6 +42,8 @@ class ReleaseNotesDirective(rst.Directive):
         'collapse-pre-releases': directives.flag,
         'earliest-version': directives.unchanged,
         'stop-at-branch-base': directives.flag,
+        'ignore-notes': directives.unchanged,
+        'unreleased-version-title': directives.unchanged,
     }
 
     def run(self):
@@ -57,6 +62,10 @@ class ReleaseNotesDirective(rst.Directive):
         reporoot = repo.Repo.discover(reporoot).path
         relnotessubdir = self.options.get('relnotessubdir',
                                           defaults.RELEASE_NOTES_SUBDIR)
+        ignore_notes = [
+            name.strip()
+            for name in self.options.get('ignore-notes', '').split(',')
+        ]
         conf = config.Config(reporoot, relnotessubdir)
         opt_overrides = {}
         if 'notesdir' in self.options:
@@ -72,8 +81,14 @@ class ReleaseNotesDirective(rst.Directive):
         if 'earliest-version' in self.options:
             opt_overrides['earliest_version'] = self.options.get(
                 'earliest-version')
+        if 'unreleased-version-title' in self.options:
+            opt_overrides['unreleased_version_title'] = self.options.get(
+                'unreleased-version-title')
+
         if branch:
             opt_overrides['branch'] = branch
+        if ignore_notes:
+            opt_overrides['ignore_notes'] = ignore_notes
         conf.override(**opt_overrides)
 
         notesdir = os.path.join(relnotessubdir, conf.notesdir)
